/*!
 * Copyright (c) 2022 Digital Credentials Consortium. All rights reserved.
 */
export type Type = string | string[];
export interface ImageObject {
    id: string;
    type?: Type;
    [x: string]: any;
}
export interface LinkedDataObject {
    id?: string;
    type?: Type;
    name?: string;
    image?: string | ImageObject;
}
export interface IssuerObject extends LinkedDataObject {
    id: string;
    url?: string;
    [x: string]: any;
}
export type VerifiableCredential = VCDIVerifiableCredential | CompactJWT;
export type CompactJWT = string;
export interface VCDIVerifiableCredential extends LinkedDataObject {
    '@context': string[] | any;
    id?: string;
    type: Type;
    issuer: string | IssuerObject;
    issuanceDate: string;
    expirationDate?: string;
    credentialSubject: CredentialSubject;
    credentialStatus?: CredentialStatus;
    credentialSchema?: CredentialSchema;
    evidence?: Evidence | Evidence[];
    refreshService?: RefreshService;
    termsOfUse?: any;
    proof?: any;
    [x: string]: any;
}
export interface CredentialSubject extends LinkedDataObject {
    [x: string]: any;
}
export interface CredentialStatus extends LinkedDataObject {
    id: string;
    type: Type;
    [x: string]: any;
    statusPurpose?: string;
    statusListIndex?: string | number;
    statusListCredential?: string;
}
export interface CredentialSchema {
    id: string;
    type: string;
}
export interface RefreshService {
    id: string;
    type: string;
}
export interface Evidence extends LinkedDataObject {
}
